Record<V> class

Stores a value associated with a given HLC

Constructors

Record(V? value, bool isDeleted, Hlc hlc, Hlc modified)

Properties

hashCode → int
The hash code for this object.
no setteroverride
hlc → Hlc
final
isDeleted → bool
final
modified → Hlc
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → V?
final

Methods

copyWith(V? value, bool isDeleted, Hlc hlc, Hlc modified) → Record<V>
Convenience method to implicitly copy the record type
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override